@@ -1,5 +1,5 @@
 /*
- * hdhomerun_record.c
+ * hdhomerun_device.c
  *
  * Copyright  2006 Silicondust Engineering Ltd. <www.silicondust.com>.
  *
@@ -209,6 +209,16 @@ uint32_t hdhomerun_device_get_device_ip(struct hdhomerun_device_t *hd)
 	return hdhomerun_control_get_device_ip(hd->cs);
 }
 
+uint32_t hdhomerun_device_get_device_id_requested(struct hdhomerun_device_t *hd)
+{
+	return hdhomerun_control_get_device_id_requested(hd->cs);
+}
+
+uint32_t hdhomerun_device_get_device_ip_requested(struct hdhomerun_device_t *hd)
+{
+	return hdhomerun_control_get_device_ip_requested(hd->cs);
+}
+
 unsigned int hdhomerun_device_get_tuner(struct hdhomerun_device_t *hd)
 {
 	return hd->tuner;
@@ -222,7 +232,7 @@ struct hdhomerun_control_sock_t *hdhomerun_device_get_control_sock(struct hdhome
 struct hdhomerun_video_sock_t *hdhomerun_device_get_video_sock(struct hdhomerun_device_t *hd)
 {
 	if (!hd->vs) {
-		hd->vs = hdhomerun_video_create(0, VIDEO_DATA_BUFFER_SIZE_1S);
+		hd->vs = hdhomerun_video_create(0, VIDEO_DATA_BUFFER_SIZE_1S * 2);
 	}
 	return hd->vs;
 }
@@ -245,6 +255,55 @@ static uint32_t hdhomerun_device_get_status_parse(const char *status_str, const
 	return (uint32_t)value;
 }
 
+unsigned int hdhomerun_device_get_tuner_status_ss_color(struct hdhomerun_tuner_status_t *status)
+{
+	unsigned int ss_yellow_min;
+	unsigned int ss_green_min;
+
+	if (strstr(status->lock_str, "8vsb")) {
+		ss_yellow_min = 50;	/* -30dBmV */
+		ss_green_min = 75;	/* -15dBmV */
+	} else if (strstr(status->lock_str, "qam64")) {
+		ss_yellow_min = 75;	/* -15dBmV */
+		ss_green_min = 90;	/* -6dBmV */
+	} else if (strstr(status->lock_str, "qam256")) {
+		ss_yellow_min = 80;	/* -12dBmV */
+		ss_green_min = 90;	/* -6dBmV */
+	} else {
+		return HDHOMERUN_STATUS_COLOR_NEUTRAL;
+	}
+
+	if (status->signal_strength >= ss_green_min) {
+		return HDHOMERUN_STATUS_COLOR_GREEN;
+	}
+	if (status->signal_strength >= ss_yellow_min) {
+		return HDHOMERUN_STATUS_COLOR_YELLOW;
+	}
+
+	return HDHOMERUN_STATUS_COLOR_RED;
+}
+
+unsigned int hdhomerun_device_get_tuner_status_snq_color(struct hdhomerun_tuner_status_t *status)
+{
+	if (status->signal_to_noise_quality >= 40) {
+		return HDHOMERUN_STATUS_COLOR_GREEN;
+	}
+	if (status->signal_to_noise_quality >= 25) {
+		return HDHOMERUN_STATUS_COLOR_YELLOW;
+	}
+
+	return HDHOMERUN_STATUS_COLOR_RED;
+}
+
+unsigned int hdhomerun_device_get_tuner_status_seq_color(struct hdhomerun_tuner_status_t *status)
+{
+	if (status->symbol_error_quality >= 100) {
+		return HDHOMERUN_STATUS_COLOR_GREEN;
+	}
+
+	return HDHOMERUN_STATUS_COLOR_RED;
+}
+
 int hdhomerun_device_get_tuner_status(struct hdhomerun_device_t *hd, struct hdhomerun_tuner_status_t *status)
 {
 	memset(status, 0, sizeof(struct hdhomerun_tuner_status_t));
@@ -509,9 +568,9 @@ int hdhomerun_device_set_var(struct hdhomerun_device_t *hd, const char *name, co
 
 int hdhomerun_device_wait_for_lock(struct hdhomerun_device_t *hd, struct hdhomerun_tuner_status_t *status)
 {
-	/* Wait for up to 1.5 seconds for lock. */
+	/* Wait for up to 2.5 seconds for lock. */
 	int i;
-	for (i = 0; i < 6; i++) {
+	for (i = 0; i < 10; i++) {
 		usleep(250000);
 
 		/* Get status to check for lock. Quality numbers will not be valid yet. */
