@@ -23,7 +23,7 @@ extern "C" {
 
 struct hdhomerun_dhcp_t;
 
-extern struct hdhomerun_dhcp_t *hdhomerun_dhcp_create(void);
+extern struct hdhomerun_dhcp_t *hdhomerun_dhcp_create(uint32_t bind_address);
 extern void hdhomerun_dhcp_destroy(struct hdhomerun_dhcp_t *dhcp);
 
 #ifdef __cplusplus
